@@ -1,6 +1,6 @@
-#![cfg(all(target_os = "linux", not(target_env = "kernel")))]
+#![cfg(target_os = "linux")]
 #![doc = include_str!("../README.md")]
-#![doc(html_root_url = "https://docs.rs/selinux/0.4.3")]
+#![doc(html_root_url = "https://docs.rs/selinux/0.4.5")]
 #![allow(clippy::upper_case_acronyms)]
 #![warn(
     unsafe_op_in_unsafe_fn,
@@ -37,22 +37,6 @@
 )]
 */
 
-use std::borrow::Cow;
-use std::collections::{hash_map, HashMap};
-use std::convert::TryFrom;
-use std::ffi::{CStr, CString};
-use std::marker::PhantomData;
-use std::mem::MaybeUninit;
-use std::os::raw::{c_char, c_int, c_uint, c_void};
-use std::os::unix::io::AsRawFd;
-use std::path::Path;
-use std::{cmp, fmt, io, mem, ptr, slice, str};
-
-use selinux_sys::pid_t;
-
-#[macro_use]
-extern crate bitflags;
-
 #[cfg(test)]
 mod tests;
 
@@ -73,6 +57,22 @@ pub mod policy;
 /// Utilities.
 pub mod utils;
 
+use std::borrow::Cow;
+use std::collections::{hash_map, HashMap};
+use std::convert::TryFrom;
+use std::ffi::{CStr, CString};
+use std::marker::PhantomData;
+use std::mem::MaybeUninit;
+use std::os::raw::{c_char, c_int, c_uint, c_void};
+use std::os::unix::io::AsRawFd;
+use std::path::Path;
+use std::{cmp, fmt, io, mem, ptr, slice, str};
+
+use selinux_sys::pid_t;
+
+#[macro_use]
+extern crate bitflags;
+
 use errors::{Error, Result};
 use utils::*;
 
