@@ -1,5 +1,3 @@
-#![cfg(all(test, target_os = "linux", not(target_env = "kernel")))]
-
 use std::collections::{HashMap, HashSet};
 use std::convert::TryFrom;
 use std::ffi::CStr;
@@ -594,7 +592,7 @@ fn security_class_new() {
 
     let _name = sc.full_access_vector_name(0).unwrap();
     let _name = sc.full_access_vector_name(1).unwrap();
-    sc.full_access_vector_name(u32::MAX).unwrap_err();
+    let _name = sc.full_access_vector_name(u32::MAX).unwrap();
 
     sc.access_vector_bit("invalid").unwrap_err();
 
